@@ -1,5 +1,5 @@
 """Top-level package for AuDoLab."""
 
 __author__ = """Arne Tillmann"""
-__email__ = 'arne.tillmann.vellmar@gmail.com'
-__version__ = '0.1.2'
+__email__ = "arne.tillmann.vellmar@gmail.com"
+__version__ = '0.1.5'
